# DO NOT EDIT! GENERATED BY Makefile.PL

$libmemcached_func = {
  'memcached_add' => 1,
  'memcached_add_by_key' => 1,
  'memcached_analyze' => 1,
  'memcached_analyze_free' => 1,
  'memcached_append' => 1,
  'memcached_append_by_key' => 1,
  'memcached_autoeject' => 1,
  'memcached_behavior_get' => 1,
  'memcached_behavior_get_distribution' => 1,
  'memcached_behavior_get_distribution_hash' => 1,
  'memcached_behavior_get_key_hash' => 1,
  'memcached_behavior_set' => 1,
  'memcached_behavior_set_distribution' => 1,
  'memcached_behavior_set_distribution_hash' => 1,
  'memcached_behavior_set_key_hash' => 1,
  'memcached_bucket_set' => 1,
  'memcached_c_str' => 1,
  'memcached_callback_get' => 1,
  'memcached_callback_set' => 1,
  'memcached_cas' => 1,
  'memcached_cas_by_key' => 1,
  'memcached_clone' => 1,
  'memcached_continue' => 1,
  'memcached_create' => 1,
  'memcached_decrement' => 1,
  'memcached_decrement_by_key' => 1,
  'memcached_decrement_with_initial' => 1,
  'memcached_decrement_with_initial_by_key' => 1,
  'memcached_delete' => 1,
  'memcached_delete_by_key' => 1,
  'memcached_destroy_sasl_auth_data' => 1,
  'memcached_dump' => 1,
  'memcached_error' => 1,
  'memcached_error_print' => 1,
  'memcached_exist' => 1,
  'memcached_exist_by_key' => 1,
  'memcached_failed' => 1,
  'memcached_fatal' => 1,
  'memcached_fetch' => 1,
  'memcached_fetch_execute' => 1,
  'memcached_fetch_result' => 1,
  'memcached_flush' => 1,
  'memcached_flush_buffers' => 1,
  'memcached_free' => 1,
  'memcached_generate_hash' => 1,
  'memcached_generate_hash_value' => 1,
  'memcached_get' => 1,
  'memcached_get_by_key' => 1,
  'memcached_get_hashkit' => 1,
  'memcached_get_memory_allocators' => 1,
  'memcached_get_memory_allocators_context' => 1,
  'memcached_get_sasl_callbacks' => 1,
  'memcached_get_user_data' => 1,
  'memcached_increment' => 1,
  'memcached_increment_by_key' => 1,
  'memcached_increment_with_initial' => 1,
  'memcached_increment_with_initial_by_key' => 1,
  'memcached_instance_next_retry' => 1,
  'memcached_last_error' => 1,
  'memcached_last_error_errno' => 1,
  'memcached_last_error_message' => 1,
  'memcached_lib_version' => 1,
  'memcached_mget' => 1,
  'memcached_mget_by_key' => 1,
  'memcached_mget_execute' => 1,
  'memcached_mget_execute_by_key' => 1,
  'memcached_prepend' => 1,
  'memcached_prepend_by_key' => 1,
  'memcached_push' => 1,
  'memcached_query_id' => 1,
  'memcached_quit' => 1,
  'memcached_replace' => 1,
  'memcached_replace_by_key' => 1,
  'memcached_reset' => 1,
  'memcached_reset_last_disconnected_server' => 1,
  'memcached_result_cas' => 1,
  'memcached_result_create' => 1,
  'memcached_result_flags' => 1,
  'memcached_result_free' => 1,
  'memcached_result_key_length' => 1,
  'memcached_result_key_value' => 1,
  'memcached_result_length' => 1,
  'memcached_result_reset' => 1,
  'memcached_result_set_expiration' => 1,
  'memcached_result_set_flags' => 1,
  'memcached_result_set_value' => 1,
  'memcached_result_take_value' => 1,
  'memcached_result_value' => 1,
  'memcached_return_t' => 1,
  'memcached_server_add' => 1,
  'memcached_server_add_udp' => 1,
  'memcached_server_add_udp_with_weight' => 1,
  'memcached_server_add_unix_socket' => 1,
  'memcached_server_add_unix_socket_with_weight' => 1,
  'memcached_server_add_with_weight' => 1,
  'memcached_server_by_key' => 1,
  'memcached_server_count' => 1,
  'memcached_server_cursor' => 1,
  'memcached_server_error' => 1,
  'memcached_server_error_reset' => 1,
  'memcached_server_error_return' => 1,
  'memcached_server_free' => 1,
  'memcached_server_get_last_disconnect' => 1,
  'memcached_server_instance_by_position' => 1,
  'memcached_server_list_append' => 1,
  'memcached_server_list_append_with_weight' => 1,
  'memcached_server_list_count' => 1,
  'memcached_server_list_free' => 1,
  'memcached_server_major_version' => 1,
  'memcached_server_micro_version' => 1,
  'memcached_server_minor_version' => 1,
  'memcached_server_name' => 1,
  'memcached_server_port' => 1,
  'memcached_server_push' => 1,
  'memcached_server_response_count' => 1,
  'memcached_server_srcport' => 1,
  'memcached_server_type' => 1,
  'memcached_servers_parse' => 1,
  'memcached_servers_reset' => 1,
  'memcached_set' => 1,
  'memcached_set_by_key' => 1,
  'memcached_set_encoding_key' => 1,
  'memcached_set_hashkit' => 1,
  'memcached_set_memory_allocators' => 1,
  'memcached_set_sasl_auth_data' => 1,
  'memcached_set_sasl_callbacks' => 1,
  'memcached_set_user_data' => 1,
  'memcached_size' => 1,
  'memcached_stat' => 1,
  'memcached_stat_execute' => 1,
  'memcached_stat_free' => 1,
  'memcached_stat_get_keys' => 1,
  'memcached_stat_get_value' => 1,
  'memcached_stat_servername' => 1,
  'memcached_strerror' => 1,
  'memcached_string_param' => 1,
  'memcached_string_printf' => 1,
  'memcached_success' => 1,
  'memcached_touch' => 1,
  'memcached_touch_by_key' => 1,
  'memcached_verbosity' => 1,
  'memcached_version' => 1
};

