# DO NOT EDIT! GENERATED BY Makefile.PL

$libmemcached_const = {
  'MEMCACHED_AUTH_CONTINUE' => 'memcached_return_t',
  'MEMCACHED_AUTH_FAILURE' => 'memcached_return_t',
  'MEMCACHED_AUTH_PROBLEM' => 'memcached_return_t',
  'MEMCACHED_BAD_KEY_PROVIDED' => 'memcached_return_t',
  'MEMCACHED_BEHAVIOR_AUTO_EJECT_HOSTS' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_BINARY_PROTOCOL' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_BUFFER_REQUESTS' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_CACHE_LOOKUPS' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_CONNECT_TIMEOUT' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_CORK' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_DEAD_TIMEOUT' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_DISTRIBUTION' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_HASH' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_HASH_WITH_PREFIX_KEY' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_IO_KEY_PREFETCH' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_KETAMA' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_KETAMA_HASH' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_KETAMA_WEIGHTED' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_LOAD_FROM_FILE' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_MAX' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_NOREPLY' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_NO_BLOCK' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_NUMBER_OF_REPLICAS' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_POLL_TIMEOUT' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_RANDOMIZE_REPLICA_READ' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_RCV_TIMEOUT' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_REMOVE_FAILED_SERVERS' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_RETRY_TIMEOUT' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_SERVER_FAILURE_LIMIT' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_SERVER_TIMEOUT_LIMIT' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_SND_TIMEOUT' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_SORT_HOSTS' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_SUPPORT_CAS' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_TCP_KEEPALIVE' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_TCP_KEEPIDLE' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_TCP_NODELAY' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_USER_DATA' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_USE_UDP' => 'memcached_behavior_t',
  'MEMCACHED_BEHAVIOR_VERIFY_KEY' => 'memcached_behavior_t',
  'MEMCACHED_BUFFERED' => 'memcached_return_t',
  'MEMCACHED_CALLBACK_CLEANUP_FUNCTION' => 'memcached_callback_t',
  'MEMCACHED_CALLBACK_CLONE_FUNCTION' => 'memcached_callback_t',
  'MEMCACHED_CALLBACK_DELETE_TRIGGER' => 'memcached_callback_t',
  'MEMCACHED_CALLBACK_GET_FAILURE' => 'memcached_callback_t',
  'MEMCACHED_CALLBACK_MAX' => 'memcached_callback_t',
  'MEMCACHED_CALLBACK_NAMESPACE' => 'memcached_callback_t',
  'MEMCACHED_CALLBACK_PREFIX_KEY' => 'memcached_callback_t',
  'MEMCACHED_CALLBACK_USER_DATA' => 'memcached_callback_t',
  'MEMCACHED_CLIENT_ERROR' => 'memcached_return_t',
  'MEMCACHED_CONNECTION_BIND_FAILURE' => 'memcached_return_t',
  'MEMCACHED_CONNECTION_FAILURE' => 'memcached_return_t',
  'MEMCACHED_CONNECTION_SOCKET_CREATE_FAILURE' => 'memcached_return_t',
  'MEMCACHED_CONNECTION_TCP' => 'memcached_connection_t',
  'MEMCACHED_CONNECTION_UDP' => 'memcached_connection_t',
  'MEMCACHED_CONNECTION_UNIX_SOCKET' => 'memcached_connection_t',
  'MEMCACHED_CONTINUUM_ADDITION' => 'defines',
  'MEMCACHED_CONTINUUM_SIZE' => 'defines',
  'MEMCACHED_DATA_DOES_NOT_EXIST' => 'memcached_return_t',
  'MEMCACHED_DATA_EXISTS' => 'memcached_return_t',
  'MEMCACHED_DEFAULT_CONNECT_TIMEOUT' => 'defines',
  'MEMCACHED_DEFAULT_PORT' => 'defines',
  'MEMCACHED_DEFAULT_PORT_STRING' => 'defines',
  'MEMCACHED_DEFAULT_TIMEOUT' => 'defines',
  'MEMCACHED_DELETED' => 'memcached_return_t',
  'MEMCACHED_DEPRECATED' => 'memcached_return_t',
  'MEMCACHED_DISTRIBUTION_CONSISTENT' => 'memcached_server_distribution_t',
  'MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA' => 'memcached_server_distribution_t',
  'MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA_SPY' => 'memcached_server_distribution_t',
  'MEMCACHED_DISTRIBUTION_CONSISTENT_MAX' => 'memcached_server_distribution_t',
  'MEMCACHED_DISTRIBUTION_CONSISTENT_WEIGHTED' => 'memcached_server_distribution_t',
  'MEMCACHED_DISTRIBUTION_MODULA' => 'memcached_server_distribution_t',
  'MEMCACHED_DISTRIBUTION_RANDOM' => 'memcached_server_distribution_t',
  'MEMCACHED_DISTRIBUTION_VIRTUAL_BUCKET' => 'memcached_server_distribution_t',
  'MEMCACHED_E2BIG' => 'memcached_return_t',
  'MEMCACHED_END' => 'memcached_return_t',
  'MEMCACHED_ERRNO' => 'memcached_return_t',
  'MEMCACHED_ERROR' => 'memcached_return_t',
  'MEMCACHED_EXPIRATION_NOT_ADD' => 'defines',
  'MEMCACHED_FAILURE' => 'memcached_return_t',
  'MEMCACHED_FAIL_UNIX_SOCKET' => 'memcached_return_t',
  'MEMCACHED_FETCH_NOTFINISHED' => 'memcached_return_t',
  'MEMCACHED_HASH_CRC' => 'memcached_hash_t',
  'MEMCACHED_HASH_CUSTOM' => 'memcached_hash_t',
  'MEMCACHED_HASH_DEFAULT' => 'memcached_hash_t',
  'MEMCACHED_HASH_FNV1A_32' => 'memcached_hash_t',
  'MEMCACHED_HASH_FNV1A_64' => 'memcached_hash_t',
  'MEMCACHED_HASH_FNV1_32' => 'memcached_hash_t',
  'MEMCACHED_HASH_FNV1_64' => 'memcached_hash_t',
  'MEMCACHED_HASH_HSIEH' => 'memcached_hash_t',
  'MEMCACHED_HASH_JENKINS' => 'memcached_hash_t',
  'MEMCACHED_HASH_MAX' => 'memcached_hash_t',
  'MEMCACHED_HASH_MD5' => 'memcached_hash_t',
  'MEMCACHED_HASH_MURMUR' => 'memcached_hash_t',
  'MEMCACHED_HASH_MURMUR3' => 'memcached_hash_t',
  'MEMCACHED_HOST_LOOKUP_FAILURE' => 'memcached_return_t',
  'MEMCACHED_INVALID_ARGUMENTS' => 'memcached_return_t',
  'MEMCACHED_INVALID_HOST_PROTOCOL' => 'memcached_return_t',
  'MEMCACHED_IN_PROGRESS' => 'memcached_return_t',
  'MEMCACHED_ITEM' => 'memcached_return_t',
  'MEMCACHED_KEY_TOO_BIG' => 'memcached_return_t',
  'MEMCACHED_MAXIMUM_INTEGER_DISPLAY_LENGTH' => 'defines',
  'MEMCACHED_MAXIMUM_RETURN' => 'memcached_return_t',
  'MEMCACHED_MAX_BUFFER' => 'defines',
  'MEMCACHED_MAX_HOST_SORT_LENGTH' => 'defines',
  'MEMCACHED_MAX_KEY' => 'defines',
  'MEMCACHED_MEMORY_ALLOCATION_FAILURE' => 'memcached_return_t',
  'MEMCACHED_NOTFOUND' => 'memcached_return_t',
  'MEMCACHED_NOTSTORED' => 'memcached_return_t',
  'MEMCACHED_NOT_SUPPORTED' => 'memcached_return_t',
  'MEMCACHED_NO_KEY_PROVIDED' => 'memcached_return_t',
  'MEMCACHED_NO_SERVERS' => 'memcached_return_t',
  'MEMCACHED_PARSE_ERROR' => 'memcached_return_t',
  'MEMCACHED_PARSE_USER_ERROR' => 'memcached_return_t',
  'MEMCACHED_PARTIAL_READ' => 'memcached_return_t',
  'MEMCACHED_POINTS_PER_SERVER' => 'defines',
  'MEMCACHED_POINTS_PER_SERVER_KETAMA' => 'defines',
  'MEMCACHED_PREFIX_KEY_MAX_SIZE' => 'defines',
  'MEMCACHED_PROTOCOL_ERROR' => 'memcached_return_t',
  'MEMCACHED_READ_FAILURE' => 'memcached_return_t',
  'MEMCACHED_SERVER_ERROR' => 'memcached_return_t',
  'MEMCACHED_SERVER_FAILURE_DEAD_TIMEOUT' => 'defines',
  'MEMCACHED_SERVER_FAILURE_LIMIT' => 'defines',
  'MEMCACHED_SERVER_FAILURE_RETRY_TIMEOUT' => 'defines',
  'MEMCACHED_SERVER_MARKED_DEAD' => 'memcached_return_t',
  'MEMCACHED_SERVER_MEMORY_ALLOCATION_FAILURE' => 'memcached_return_t',
  'MEMCACHED_SERVER_TEMPORARILY_DISABLED' => 'memcached_return_t',
  'MEMCACHED_SERVER_TIMEOUT_LIMIT' => 'defines',
  'MEMCACHED_SOME_ERRORS' => 'memcached_return_t',
  'MEMCACHED_STAT' => 'memcached_return_t',
  'MEMCACHED_STORED' => 'memcached_return_t',
  'MEMCACHED_STRIDE' => 'defines',
  'MEMCACHED_SUCCESS' => 'memcached_return_t',
  'MEMCACHED_TIMEOUT' => 'memcached_return_t',
  'MEMCACHED_UNKNOWN_READ_FAILURE' => 'memcached_return_t',
  'MEMCACHED_UNKNOWN_STAT_KEY' => 'memcached_return_t',
  'MEMCACHED_VALUE' => 'memcached_return_t',
  'MEMCACHED_VERSION_STRING_LENGTH' => 'defines',
  'MEMCACHED_WRITE_FAILURE' => 'memcached_return_t'
};

